@@ -1,40 +1,57 @@
 
+from generalpackager.api.shared import _SharedAPI
 from generalpackager import PACKAGER_GITHUB_API
+from generallibrary import Recycle, deco_cache
+from generalfile import Path
 
 import requests
 import json
 import re
+from git import Repo
 
 
-class GitHub:
+class GitHub(Recycle, _SharedAPI):
     """ Tools to interface a GitHub Repository. """
-    def __init__(self, name, owner=None):
+    _recycle_keys = {"name": str, "owner": str}
+
+    def __init__(self, name=None, owner=None):
+        if name is None:
+            name = "generalpackager"
         if owner is None:
             owner = "ManderaGeneral"
-
         self.name = name
         self.owner = owner
 
-        self.url = self.get_url(name=self.name, owner=self.owner)
+        self.url = f"https://github.com/{self.owner}/{self.name}"
 
-        # if not self.is_url_functioning():
-        #     raise AssertionError(f"Url for {self.name} is not functioning.")
+    def exists(self):
+        """ Return whether this API's target exists. """
+        return requests.get(url=self.url).status_code == 200
 
-    @classmethod
-    def is_creatable(cls, name, owner):
-        """ Return whether this API can be created. """
-        return requests.get(url=cls.get_url(name=name, owner=owner)).status_code == 200
+    def download(self, path, overwrite=False):
+        """ Clone a GitHub repo into a path.
+            Creates a folder with Package's name first.
+            Target must be empty.
 
-    @staticmethod
-    def get_url(name, owner):
-        """ Get static URL from owner and name. """
-        return f"https://github.com/{owner}/{name}"
+            :param generalpackager.Packager self:
+            :param path:
+            :param overwrite: """
+        path = Path(path) / self.name
 
-    def is_url_functioning(self, url=None):
-        """ Checks name, owner and token all in one. """
-        return self._request(url=url).status_code == 200
+        if path.exists():
+            if overwrite:
+                path.delete()
+            else:
+                raise AttributeError(f"Clone target exists and overwrite is False.")
 
-    def api_url(self, endpoint=None):
+        Repo.clone_from(url=self.url, to_path=path)
+        return path
+
+    def get_owners_packages(self):
+        """ Get a set of a owner's packages' names on GitHub. """
+        return set(re.findall(f'"/{self.owner}/(.+)/hovercard"', requests.get(f"https://github.com/{self.owner}?tab=repositories").text))
+
+    def _api_url(self, endpoint=None):
         """ Get URL from owner, name and enpoint. """
         return "/".join(("https://api.github.com", "repos", self.owner, self.name) + ((endpoint, ) if endpoint else ()))
 
@@ -48,7 +65,6 @@ class GitHub:
         """ Set a website for the GitHub repository. """
         return self._request(method="patch", name=self.name, homepage=website)
 
-
     def get_topics(self):
         """ Get a list of topics in the GitHub repository.
 
@@ -61,7 +77,6 @@ class GitHub:
             :param str topics: """
         return self._request(method="put", endpoint="topics", names=topics)
 
-
     def get_description(self):
         """ Get a string of description in the GitHub repository.
 
@@ -72,6 +87,7 @@ class GitHub:
         """ Set a description for the GitHub repository. """
         return self._request(method="patch", name=self.name, description=description)
 
+    @deco_cache()
     def _request(self, method="get", url=None, endpoint=None, **data):
         """ :rtype: requests.Response """
         method = getattr(requests, method.lower())
@@ -82,18 +98,10 @@ class GitHub:
         }
         if data:
             kwargs["data"] = json.dumps(data)
-
         if url is None:
-            url = self.api_url(endpoint=endpoint)
+            url = self._api_url(endpoint=endpoint)
         return method(url=url, **kwargs)
 
-    @staticmethod
-    def get_users_packages(user=None):
-        """ Get a set of a user's packages' names on GitHub. """
-        if user is None:
-            user = "ManderaGeneral"
-        return set(re.findall(f'"/{user}/([a-z]*)"', requests.get(f"https://github.com/{user}?tab=repositories").text))
-
 
 
 
